@@ -2,7 +2,7 @@
 import logging
 
 import stripe
-from django.utils.translation import ugettext_lazy as _
+from django.utils.translation import gettext_lazy as _
 from rest_framework import serializers
 from rest_framework.exceptions import ValidationError
 from rest_framework.serializers import JSONField, ModelSerializer
